# clr-loader

![CI](https://github.com/pythonnet/clr-loader/workflows/Python%20Tests/badge.svg)
![Pypi](https://img.shields.io/pypi/v/clr-loader.svg)
![License](https://img.shields.io/badge/license-MIT-blue.svg?maxAge=3600)

Implements a generic interface for loading one of the CLR (.NET) runtime implementations and calling simple functions on them.
